VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package shinyKGode

Package {shinyKGode}


Type: Package
Title: An Interactive Application for ODE Parameter Inference Using Gradient Matching
Version: 1.0.5
Author: Joe Wandy
Maintainer: Joe Wandy <joe.wandy@glasgow.ac.uk>
Description: An interactive Shiny application to perform fast parameter inference on dynamical systems (described by ordinary differential equations) using gradient matching. Please see the project page for more details.
License: GPL-2
URL: https://github.com/joewandy/shinyKGode
Encoding: UTF-8
LazyData: true
Imports: shiny (≥ 1.0.5), shinyjs (≥ 0.9.1), ggplot2 (≥ 2.2.1), reshape2 (≥ 1.4.2), gridExtra (≥ 2.3), mvtnorm (≥ 1.0.6), KGode (≥ 1.0.0), XML (≥ 3.98.1.9),
Depends: pracma (≥ 2.0.7), pspline (≥ 1.0.18)
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2018-02-12 12:02:02 UTC; joewandy
Repository: CRAN
Date/Publication: 2018-02-12 12:57:59 UTC

shinyKGode: A Shiny package for gradient matching parameter inference on ordinary differential equations.

Description

The shinyKGode package provides three main functions: a friendly Shiny-based user-interface to run gradient matching to solve ordinary differential equations, a selection of three built-in models and also the ability to import user-defined differential equations and perform parameter inference on them.


This function will start ShinyKGode.

Description

An interactive Shiny application for running gradient matching to approximate ODEs.

Usage

startShinyKGode()

Details

Start ShinyKGode

This starts the ShinyKGode application on the user's local computer.

Value

Nothing

Examples

{
if(interactive()){
  startShinyKGode()
  }
}

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.